==> script.module.dandyscrapers-17.10.30.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/icefilms.py <==
import re,base64
from md_request import open_url
import xbmc
import urllib
from ..scraper import Scraper
from ..common import clean_title,clean_search,non_func_hosts
import urlresolver
User_Agent = 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Safari/537.36'

#non_func_hosts = ("watchers","rapidvideo")



class icefilms(Scraper):
    domains = ['https://icefilms.is']
    name = "IceFilms"
    sources = []

    def __init__(self):
        self.base_link = 'https://icefilms.is'
        self.sources = []

    def scrape_movie(self, title, year, imdb, debrid=False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/newmov.php?menu=search&query=%s' %(self.base_link,search_id.replace(' ','+'))
            headers = {'User_Agent':User_Agent}
            html = open_url(start_url,headers=headers,verify=False,timeout=3).content
            Regex = re.compile('class="title"><a href="(.+?)".+?>(.+?)</a>.+?class="year">(.+?)</div>',re.DOTALL).findall(html)
            for item_url,name,date in Regex:
                if clean_title(title).lower() == clean_title(name).lower():
                    if year in date:
                        movie_link = self.base_link+item_url
                        self.get_source(movie_link)
                
            return self.sources
        except Exception, argument:
            return self.sources

    def scrape_episode(self,title, show_year, year, season, episode, imdb, tvdb, debrid = False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/newmov.php?menu=searchshow&query=%s' %(self.base_link,search_id.replace(' ','+'))
            #print 'SEARCH > '+start_url
            headers = {'User_Agent':User_Agent}
            html = open_url(start_url,headers=headers).content
            Regex = re.compile('class="title"><a href="(.+?)".+?>(.+?)</a>',re.DOTALL).findall(html)
            for item_url,name in Regex:
                #print item_url
                if clean_title(title).lower() == clean_title(name).lower():
                    item_url = self.base_link+item_url
                    movie_link =  '%s/season/%s/episode/%s' %(item_url,season,episode)
                    #print 'EPISODE URL > '+movie_link
                    self.get_source(movie_link)
                
            return self.sources
        except Exception, argument:
            return self.sources

    def get_source(self,movie_link):
        try:
            html = open_url(movie_link).content
            page = re.compile('out.php\?link=(.+?)"',re.DOTALL).findall(html)
            for link in page:
                link = base64.b64decode(link)
                if urlresolver.HostedMediaFile(link).valid_url():
                    host = link.split('//')[1].replace('www.','')
                    host = host.split('/')[0].split('.')[0].title()
                    if not non_func_hosts(host.lower()):
                        continue
                    self.sources.append({'source':host,'quality': 'DVD','scraper': self.name,'url': link,'direct': False})
        except:
            pass

==> script.module.dandyscrapers-17.11.1.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/icefilms.py <==
import re,base64
from md_request import open_url
import xbmc
import urllib
from ..scraper import Scraper
from ..common import clean_title,clean_search,non_func_hosts
import urlresolver
User_Agent = 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Safari/537.36'

#non_func_hosts = ("watchers","rapidvideo")



class icefilms(Scraper):
    domains = ['https://icefilms.is']
    name = "IceFilms"
    sources = []

    def __init__(self):
        self.base_link = 'https://icefilms.is'
        self.sources = []

    def scrape_movie(self, title, year, imdb, debrid=False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/newmov.php?menu=search&query=%s' %(self.base_link,search_id.replace(' ','+'))
            headers = {'User_Agent':User_Agent}
            html = open_url(start_url,headers=headers,verify=False,timeout=3).content
            Regex = re.compile('class="title"><a href="(.+?)".+?>(.+?)</a>.+?class="year">(.+?)</div>',re.DOTALL).findall(html)
            for item_url,name,date in Regex:
                if clean_title(title).lower() == clean_title(name).lower():
                    if year in date:
                        movie_link = self.base_link+item_url
                        self.get_source(movie_link)
                
            return self.sources
        except Exception, argument:
            return self.sources

    def scrape_episode(self,title, show_year, year, season, episode, imdb, tvdb, debrid = False):
        try:
            search_id = clean_search(title.lower())
            start_url = '%s/newmov.php?menu=searchshow&query=%s' %(self.base_link,search_id.replace(' ','+'))
            #print 'SEARCH > '+start_url
            headers = {'User_Agent':User_Agent}
            html = open_url(start_url,headers=headers,verify=False,timeout=3).content
            Regex = re.compile('class="title"><a href="(.+?)".+?>(.+?)</a>',re.DOTALL).findall(html)
            for item_url,name in Regex:
                #print item_url
                if clean_title(title).lower() == clean_title(name).lower():
                    item_url = self.base_link+item_url
                    movie_link =  '%s/season/%s/episode/%s' %(item_url,season,episode)
                    #print 'EPISODE URL > '+movie_link
                    self.get_source(movie_link)
                
            return self.sources
        except Exception, argument:
            return self.sources

    def get_source(self,movie_link):
        try:
            html = open_url(movie_link,timeout=3).content
            page = re.compile('out.php\?link=(.+?)"',re.DOTALL).findall(html)
            for link in page:
                link = base64.b64decode(link)
                if urlresolver.HostedMediaFile(link).valid_url():
                    host = link.split('//')[1].replace('www.','')
                    host = host.split('/')[0].split('.')[0].title()
                    if not non_func_hosts(host.lower()):
                        continue
                    self.sources.append({'source':host,'quality': 'DVD','scraper': self.name,'url': link,'direct': False})
        except:
            pass
